@@ -23,6 +23,7 @@ import Data.Serialize.Put (Put, putWord8, putWord16be, putWord32be, putByteStrin
 import Data.Set (Set)
 import qualified Data.Set as Set
 import Data.Word (Word8, Word32)
+import Data.Maybe (fromMaybe)
 
 import Codec.Encryption.OpenPGP.Internal (countBits, beBSToInteger, integerToBEBS, pubkeyToMPIs)
 import Codec.Encryption.OpenPGP.Types
@@ -526,10 +527,8 @@ getPkt = do
                           symalgo <- getWord8
                           s2k <- getS2K
                           remainder <- remaining
-                          mpib <- getBytes remainder
-                          case runGet (many getMPI) mpib of
-                              Left _ -> return $ SKESKPkt pv (toFVal symalgo) s2k []
-                              Right mpis -> return $ SKESKPkt pv (toFVal symalgo) s2k mpis
+                          esk <- getByteString remainder
+                          return $ SKESKPkt pv (toFVal symalgo) s2k (if B.null esk then Nothing else Just esk)
             | t == 4 = do
                           pv <- getWord8
                           sigtype <- getWord8
@@ -649,10 +648,10 @@ putPkt (SignaturePkt sp) = do
     let bs = runPut $ put sp
     putPacketLength . fromIntegral . B.length $ bs
     putByteString bs
-putPkt (SKESKPkt pv symalgo s2k mpis) = do
+putPkt (SKESKPkt pv symalgo s2k mesk) = do
     putWord8 (0xc0 .|. 3)
     let bs2k = fromS2K s2k
-    let bsk = runPut $ mapM_ put mpis
+    let bsk = fromMaybe B.empty mesk
     putPacketLength . fromIntegral $ 2 + (B.length bs2k) + (B.length bsk)
     putWord8 pv -- should be 4
     putWord8 $ fromIntegral . fromFVal $ symalgo
