@@ -566,7 +566,7 @@ class Packet a where
 -- data Pkt = forall a. (Packet a, Show a, Eq a) => Pkt a
 data Pkt = PKESKPkt PacketVersion EightOctetKeyId PubKeyAlgorithm [MPI]
          | SignaturePkt SignaturePayload
-         | SKESKPkt PacketVersion SymmetricAlgorithm S2K [MPI]
+         | SKESKPkt PacketVersion SymmetricAlgorithm S2K (Maybe B.ByteString)
          | OnePassSignaturePkt PacketVersion SigType HashAlgorithm PubKeyAlgorithm EightOctetKeyId NestedFlag
          | SecretKeyPkt PKPayload SKAddendum
          | PublicKeyPkt PKPayload
@@ -591,7 +591,7 @@ data PKESK = PKESK
     , _pkeskMPIs :: [MPI]
     } deriving (Data, Eq, Show, Typeable)
 instance Packet PKESK where
-    data PacketType PKESK = PKESKType
+    data PacketType PKESK = PKESKType deriving (Show, Eq)
     packetType _ = PKESKType
     packetCode _ = 1
     toPkt (PKESK a b c d) = PKESKPkt a b c d
@@ -601,7 +601,7 @@ data Signature = Signature   -- FIXME?
     { _signaturePayload :: SignaturePayload
     } deriving (Data, Eq, Show, Typeable)
 instance Packet Signature where
-    data PacketType Signature = SignatureType
+    data PacketType Signature = SignatureType deriving (Show, Eq)
     packetType _ = SignatureType
     packetCode _ = 2
     toPkt (Signature a ) = SignaturePkt a
@@ -611,10 +611,10 @@ data SKESK = SKESK
     { _skeskPacketVersion :: PacketVersion
     , _skeskSymmetricAlgorithm :: SymmetricAlgorithm
     , _skeskS2K :: S2K
-    , _skeskMPIs :: [MPI]
+    , _skeskESK :: Maybe B.ByteString
     } deriving (Data, Eq, Show, Typeable)
 instance Packet SKESK where
-    data PacketType SKESK = SKESKType
+    data PacketType SKESK = SKESKType deriving (Show, Eq)
     packetType _ = SKESKType
     packetCode _ = 3
     toPkt (SKESK a b c d) = SKESKPkt a b c d
@@ -629,7 +629,7 @@ data OnePassSignature = OnePassSignature
     , _onePassSignatureNestedFlag :: NestedFlag
     } deriving (Data, Eq, Show, Typeable)
 instance Packet OnePassSignature where
-    data PacketType OnePassSignature = OnePassSignatureType
+    data PacketType OnePassSignature = OnePassSignatureType deriving (Show, Eq)
     packetType _ = OnePassSignatureType
     packetCode _ = 4
     toPkt (OnePassSignature a b c d e f) = OnePassSignaturePkt a b c d e f
@@ -640,7 +640,7 @@ data SecretKey = SecretKey
     , _secretKeySKAddendum :: SKAddendum
     } deriving (Data, Eq, Show, Typeable)
 instance Packet SecretKey where
-    data PacketType SecretKey = SecretKeyType
+    data PacketType SecretKey = SecretKeyType deriving (Show, Eq)
     packetType _ = SecretKeyType
     packetCode _ = 5
     toPkt (SecretKey a b) = SecretKeyPkt a b
@@ -650,7 +650,7 @@ data PublicKey = PublicKey
     { _publicKeyPKPayload :: PKPayload
     } deriving (Data, Eq, Show, Typeable)
 instance Packet PublicKey where
-    data PacketType PublicKey = PublicKeyType
+    data PacketType PublicKey = PublicKeyType deriving (Show, Eq)
     packetType _ = PublicKeyType
     packetCode _ = 6
     toPkt (PublicKey a) = PublicKeyPkt a
@@ -661,7 +661,7 @@ data SecretSubkey = SecretSubkey
     , _secretSubkeySKAddendum :: SKAddendum
     } deriving (Data, Eq, Show, Typeable)
 instance Packet SecretSubkey where
-    data PacketType SecretSubkey = SecretSubkeyType
+    data PacketType SecretSubkey = SecretSubkeyType deriving (Show, Eq)
     packetType _ = SecretSubkeyType
     packetCode _ = 7
     toPkt (SecretSubkey a b) = SecretSubkeyPkt a b
@@ -672,7 +672,7 @@ data CompressedData = CompressedData
     , _compressedDataPayload :: CompressedDataPayload
     } deriving (Data, Eq, Show, Typeable)
 instance Packet CompressedData where
-    data PacketType CompressedData = CompressedDataType
+    data PacketType CompressedData = CompressedDataType deriving (Show, Eq)
     packetType _ = CompressedDataType
     packetCode _ = 8
     toPkt (CompressedData a b) = CompressedDataPkt a b
@@ -682,7 +682,7 @@ data SymEncData = SymEncData
     { _symEncDataPayload :: ByteString
     } deriving (Data, Eq, Show, Typeable)
 instance Packet SymEncData where
-    data PacketType SymEncData = SymEncDataType
+    data PacketType SymEncData = SymEncDataType deriving (Show, Eq)
     packetType _ = SymEncDataType
     packetCode _ = 9
     toPkt (SymEncData a) = SymEncDataPkt a
@@ -692,7 +692,7 @@ data Marker = Marker
     { _markerPayload :: ByteString
     } deriving (Data, Eq, Show, Typeable)
 instance Packet Marker where
-    data PacketType Marker = MarkerType
+    data PacketType Marker = MarkerType deriving (Show, Eq)
     packetType _ = MarkerType
     packetCode _ = 10
     toPkt (Marker a) = MarkerPkt a
@@ -705,7 +705,7 @@ data LiteralData = LiteralData
     , _literalDataPayload :: ByteString
     } deriving (Data, Eq, Show, Typeable)
 instance Packet LiteralData where
-    data PacketType LiteralData = LiteralDataType
+    data PacketType LiteralData = LiteralDataType deriving (Show, Eq)
     packetType _ = LiteralDataType
     packetCode _ = 11
     toPkt (LiteralData a b c d) = LiteralDataPkt a b c d
@@ -715,7 +715,7 @@ data Trust = Trust
     { _trustPayload :: ByteString
     } deriving (Data, Eq, Show, Typeable)
 instance Packet Trust where
-    data PacketType Trust = TrustType
+    data PacketType Trust = TrustType deriving (Show, Eq)
     packetType _ = TrustType
     packetCode _ = 12
     toPkt (Trust a) = TrustPkt a
@@ -725,7 +725,7 @@ data UserId = UserId
     { _userIdPayload :: String
     } deriving (Data, Eq, Show, Typeable)
 instance Packet UserId where
-    data PacketType UserId = UserIdType
+    data PacketType UserId = UserIdType deriving (Show, Eq)
     packetType _ = UserIdType
     packetCode _ = 13
     toPkt (UserId a) = UserIdPkt a
@@ -735,7 +735,7 @@ data PublicSubkey = PublicSubkey
     { _publicSubkeyPKPayload :: PKPayload
     } deriving (Data, Eq, Show, Typeable)
 instance Packet PublicSubkey where
-    data PacketType PublicSubkey = PublicSubkeyType
+    data PacketType PublicSubkey = PublicSubkeyType deriving (Show, Eq)
     packetType _ = PublicSubkeyType
     packetCode _ = 14
     toPkt (PublicSubkey a) = PublicSubkeyPkt a
@@ -745,7 +745,7 @@ data UserAttribute = UserAttribute
     { _userAttributeSubPackets :: [UserAttrSubPacket]
     } deriving (Data, Eq, Show, Typeable)
 instance Packet UserAttribute where
-    data PacketType UserAttribute = UserAttributeType
+    data PacketType UserAttribute = UserAttributeType deriving (Show, Eq)
     packetType _ = UserAttributeType
     packetCode _ = 17
     toPkt (UserAttribute a) = UserAttributePkt a
@@ -756,7 +756,7 @@ data SymEncIntegrityProtectedData = SymEncIntegrityProtectedData
     , _symEncIntegrityProtectedDataPayload :: ByteString
     } deriving (Data, Eq, Show, Typeable)
 instance Packet SymEncIntegrityProtectedData where
-    data PacketType SymEncIntegrityProtectedData = SymEncIntegrityProtectedDataType
+    data PacketType SymEncIntegrityProtectedData = SymEncIntegrityProtectedDataType deriving (Show, Eq)
     packetType _ = SymEncIntegrityProtectedDataType
     packetCode _ = 18
     toPkt (SymEncIntegrityProtectedData a b) = SymEncIntegrityProtectedDataPkt a b
@@ -766,7 +766,7 @@ data ModificationDetectionCode = ModificationDetectionCode
     { _modificationDetectionCodePayload :: ByteString
     } deriving (Data, Eq, Show, Typeable)
 instance Packet ModificationDetectionCode where
-    data PacketType ModificationDetectionCode = ModificationDetectionCodeType
+    data PacketType ModificationDetectionCode = ModificationDetectionCodeType deriving (Show, Eq)
     packetType _ = ModificationDetectionCodeType
     packetCode _ = 19
     toPkt (ModificationDetectionCode a) = ModificationDetectionCodePkt a
@@ -777,7 +777,7 @@ data OtherPacket = OtherPacket
     , _otherPacketPayload :: ByteString
     } deriving (Data, Eq, Show, Typeable)
 instance Packet OtherPacket where
-    data PacketType OtherPacket = OtherPacketType
+    data PacketType OtherPacket = OtherPacketType deriving (Show, Eq)
     packetType _ = OtherPacketType
     packetCode _ = undefined -- FIXME
     toPkt (OtherPacket a b) = OtherPacketPkt a b
